@@ -18,9 +18,18 @@
 
 #include <stdlib.h>
 
+#include <retro_common_api.h>
+#include "mmdevice_common_inline.h"
+
 RETRO_BEGIN_DECLS
 
-void *mmdevice_list_new(void *u);
+void *mmdevice_list_new(const void *u, EDataFlow data_flow);
+
+/**
+ * Gets the friendly name of the provided IMMDevice.
+ * The string must be freed with free().
+ */
+char* mmdevice_name(IMMDevice *device);
 
 RETRO_END_DECLS
 
