@@ -88,7 +88,7 @@ void cheat_manager_apply_cheats(void)
 
    for (i = 0; i < cheat_st->size; i++)
    {
-      if (     cheat_st->cheats[i].state 
+      if (     cheat_st->cheats[i].state
             && cheat_st->cheats[i].handler == CHEAT_HANDLER_TYPE_EMU)
       {
          retro_ctx_cheat_info_t cheat_info;
@@ -171,13 +171,9 @@ bool cheat_manager_save(
       strlcpy(cheats_file, path, sizeof(cheats_file));
    else
    {
-      size_t len         = fill_pathname_join_special(cheats_file,
-            cheat_database, path, sizeof(cheats_file));
-      cheats_file[len  ] = '.';
-      cheats_file[len+1] = 'c';
-      cheats_file[len+2] = 'h';
-      cheats_file[len+3] = 't';
-      cheats_file[len+4] = '\0';
+      size_t len = fill_pathname_join_special(cheats_file, cheat_database,
+             path, sizeof(cheats_file));
+      strlcpy(cheats_file + len, ".cht", sizeof(cheats_file) - len);
    }
 
    if (!overwrite)
@@ -194,36 +190,27 @@ bool cheat_manager_save(
    for (i = 0; i < cheat_st->size; i++)
    {
       unsigned j;
-      char endian_key[100];
       char key[256];
-      char desc_key[128];
-      char code_key[128];
-      char enable_key[128];
-      char formatted_number[12];
- 
-      formatted_number[0] = '\0';
-      snprintf(formatted_number, sizeof(formatted_number), "cheat%u_", i);
-
-      strlcpy(endian_key, formatted_number, sizeof(endian_key));
-      strlcat(endian_key, "big_endian", sizeof(endian_key));
-      strlcpy(desc_key, formatted_number, sizeof(desc_key));
-      strlcat(desc_key, "desc", sizeof(desc_key));
-      strlcpy(code_key, formatted_number, sizeof(code_key));
-      strlcat(code_key, "code", sizeof(code_key));
-      strlcpy(enable_key, formatted_number, sizeof(enable_key));
-      strlcat(enable_key, "enable", sizeof(enable_key));
+      char var_key[128];
+      size_t _len = snprintf(var_key, sizeof(var_key), "cheat%u_", i);
 
+      strlcpy(var_key + _len, "desc", sizeof(var_key) - _len);
       if (!string_is_empty(cheat_st->cheats[i].desc))
-         config_set_string(conf, desc_key, cheat_st->cheats[i].desc);
+         config_set_string(conf, var_key, cheat_st->cheats[i].desc);
       else
-         config_set_string(conf, desc_key, cheat_st->cheats[i].code);
+         config_set_string(conf, var_key, cheat_st->cheats[i].code);
 
-      config_set_string(conf, code_key, cheat_st->cheats[i].code);
-      config_set_string(conf, enable_key,
-               cheat_st->cheats[i].state 
-            ? "true" 
+      strlcpy(var_key + _len, "code", sizeof(var_key) - _len);
+      config_set_string(conf, var_key, cheat_st->cheats[i].code);
+
+      strlcpy(var_key + _len, "enable", sizeof(var_key) - _len);
+      config_set_string(conf, var_key,
+               cheat_st->cheats[i].state
+            ? "true"
             : "false");
-      config_set_string(conf, endian_key,
+
+      strlcpy(var_key + _len, "big_endian", sizeof(var_key) - _len);
+      config_set_string(conf, var_key,
                cheat_st->cheats[i].big_endian
             ? "true"
             : "false"
@@ -538,7 +525,7 @@ bool cheat_manager_load(const char *path, bool append)
    }
 
    cheat_st->loading_cheat_offset            = orig_size;
-   cb.config_file_new_entry_cb               = 
+   cb.config_file_new_entry_cb               =
       cheat_manager_load_cb_second_pass;
    conf = config_file_new_with_callback(path, &cb);
 
@@ -622,12 +609,15 @@ void cheat_manager_update(cheat_manager_t *handle, unsigned handle_idx)
    if (!handle || !handle->cheats || handle->size == 0)
       return;
 
+   /* TODO/FIXME - localize */
    snprintf(msg, sizeof(msg),
          "Cheat: #%u [%s]: %s",
          handle_idx,
-         handle->cheats[handle_idx].state ? "ON" : "OFF",
-         handle->cheats[handle_idx].desc 
-         ? (handle->cheats[handle_idx].desc) 
+         handle->cheats[handle_idx].state
+         ? msg_hash_to_str(MENU_ENUM_LABEL_ON)
+         : msg_hash_to_str(MENU_ENUM_LABEL_OFF),
+         handle->cheats[handle_idx].desc
+         ? (handle->cheats[handle_idx].desc)
          : (handle->cheats[handle_idx].code)
          );
    runloop_msg_queue_push(msg, 1, 180, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
@@ -713,20 +703,20 @@ static bool cheat_manager_get_game_specific_filename(
       bool saving)
 {
    char s1[PATH_MAX_LENGTH];
-   struct retro_system_info system_info;
+   struct retro_system_info sysinfo;
    runloop_state_t *runloop_st = runloop_state_get_ptr();
    const char *core_name       = NULL;
    const char *game_name       = NULL;
 
-   if (!core_get_system_info(&system_info))
+   if (!core_get_system_info(&sysinfo))
       return false;
 
-   core_name = system_info.library_name;
+   core_name = sysinfo.library_name;
    game_name = path_basename_nocompression(runloop_st->name.cheatfile);
 
-   if (string_is_empty(path_cheat_database) ||
-         string_is_empty(core_name) ||
-         string_is_empty(game_name))
+   if (     string_is_empty(path_cheat_database)
+         || string_is_empty(core_name)
+         || string_is_empty(game_name))
       return false;
 
    fill_pathname_join_special(s1,
@@ -778,24 +768,24 @@ void cheat_manager_state_free(void)
    cheat_manager_free();
 }
 
-bool cheat_manager_alloc_if_empty(void)
+void cheat_manager_alloc_if_empty(void)
 {
    cheat_manager_t *cheat_st = &cheat_manager_state;
    if (!cheat_st->cheats)
       cheat_manager_new(0);
-
-   return true;
 }
 
 int cheat_manager_initialize_memory(rarch_setting_t *setting, size_t idx, bool wraparound)
 {
    unsigned i;
    retro_ctx_memory_info_t meminfo;
-   bool refresh                           = false;
    bool is_search_initialization          = (setting != NULL);
-   rarch_system_info_t *system            = &runloop_state_get_ptr()->system;
+   rarch_system_info_t *sys_info          = &runloop_state_get_ptr()->system;
    unsigned offset                        = 0;
    cheat_manager_t              *cheat_st = &cheat_manager_state;
+#ifdef HAVE_MENU
+   struct menu_state *menu_st             = menu_state_get_ptr();
+#endif
 
    cheat_st->num_memory_buffers           = 0;
    cheat_st->total_memory_size            = 0;
@@ -813,14 +803,14 @@ int cheat_manager_initialize_memory(rarch_setting_t *setting, size_t idx, bool w
       cheat_st->memory_size_list = NULL;
    }
 
-   if (system && system->mmaps.num_descriptors > 0)
+   if (sys_info && sys_info->mmaps.num_descriptors > 0)
    {
-      for (i = 0; i < system->mmaps.num_descriptors; i++)
+      for (i = 0; i < sys_info->mmaps.num_descriptors; i++)
       {
-         if ((system->mmaps.descriptors[i].core.flags 
-                  & RETRO_MEMDESC_SYSTEM_RAM) != 0 &&
-               system->mmaps.descriptors[i].core.ptr &&
-               system->mmaps.descriptors[i].core.len > 0)
+         if ((sys_info->mmaps.descriptors[i].core.flags
+                  & RETRO_MEMDESC_SYSTEM_RAM) != 0
+               && sys_info->mmaps.descriptors[i].core.ptr
+               && sys_info->mmaps.descriptors[i].core.len > 0)
          {
             cheat_st->num_memory_buffers++;
 
@@ -843,12 +833,12 @@ int cheat_manager_initialize_memory(rarch_setting_t *setting, size_t idx, bool w
                   cheat_st->memory_size_list = val;
             }
 
-            cheat_st->memory_buf_list[cheat_st->num_memory_buffers - 1] = (uint8_t*)system->mmaps.descriptors[i].core.ptr;
-            cheat_st->memory_size_list[cheat_st->num_memory_buffers - 1] = (unsigned)system->mmaps.descriptors[i].core.len;
-            cheat_st->total_memory_size += system->mmaps.descriptors[i].core.len;
+            cheat_st->memory_buf_list[cheat_st->num_memory_buffers  - 1] = (uint8_t*)sys_info->mmaps.descriptors[i].core.ptr;
+            cheat_st->memory_size_list[cheat_st->num_memory_buffers - 1] = (unsigned)sys_info->mmaps.descriptors[i].core.len;
+            cheat_st->total_memory_size += sys_info->mmaps.descriptors[i].core.len;
 
             if (!cheat_st->curr_memory_buf)
-               cheat_st->curr_memory_buf = (uint8_t*)system->mmaps.descriptors[i].core.ptr;
+               cheat_st->curr_memory_buf = (uint8_t*)sys_info->mmaps.descriptors[i].core.ptr;
          }
       }
    }
@@ -931,19 +921,17 @@ int cheat_manager_initialize_memory(rarch_setting_t *setting, size_t idx, bool w
          offset += cheat_st->memory_size_list[i];
       }
 
+      runloop_msg_queue_push(msg_hash_to_str(MSG_CHEAT_INIT_SUCCESS), 1, 180, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+
       cheat_st->memory_search_initialized = true;
    }
 
    cheat_st->memory_initialized = true;
 
-   runloop_msg_queue_push(msg_hash_to_str(MSG_CHEAT_INIT_SUCCESS), 1, 180, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
-
 #ifdef HAVE_MENU
    if (!wraparound)
-   {
-      menu_entries_ctl(MENU_ENTRIES_CTL_SET_REFRESH, &refresh);
-      menu_driver_ctl(RARCH_MENU_CTL_SET_PREVENT_POPULATE, NULL);
-   }
+      menu_st->flags                 |=  MENU_ST_FLAG_ENTRIES_NEED_REFRESH
+                                      |  MENU_ST_FLAG_PREVENT_POPULATE;
 #endif
 
    return 0;
@@ -1024,11 +1012,15 @@ static int cheat_manager_search(enum cheat_search_type search_type)
    unsigned int bits           = 8;
    unsigned int offset         = 0;
    unsigned int i              = 0;
-   bool refresh                = false;
+#ifdef HAVE_MENU
+   struct menu_state *menu_st  = menu_state_get_ptr();
+#endif
 
-   if (cheat_st->num_memory_buffers == 0)
+   if (cheat_st->num_memory_buffers == 0 || !prev || !cheat_st->matches)
    {
-      runloop_msg_queue_push(msg_hash_to_str(MSG_CHEAT_SEARCH_NOT_INITIALIZED), 1, 180, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+      runloop_msg_queue_push(msg_hash_to_str(MSG_CHEAT_SEARCH_NOT_INITIALIZED),
+            1, 180, true, NULL,
+            MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
       return 0;
    }
 
@@ -1139,8 +1131,8 @@ static int cheat_manager_search(enum cheat_search_type search_type)
    runloop_msg_queue_push(msg, 1, 180, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
 
 #ifdef HAVE_MENU
-   menu_entries_ctl(MENU_ENTRIES_CTL_SET_REFRESH, &refresh);
-   menu_driver_ctl(RARCH_MENU_CTL_SET_PREVENT_POPULATE, NULL);
+   menu_st->flags                 |=  MENU_ST_FLAG_ENTRIES_NEED_REFRESH
+                                   |  MENU_ST_FLAG_PREVENT_POPULATE;
 #endif
    return 0;
 }
@@ -1218,17 +1210,18 @@ int cheat_manager_add_matches(const char *path,
       const char *label, unsigned type, size_t menuidx, size_t entry_idx)
 {
    char msg[100];
-   bool                refresh = false;
    unsigned          byte_part = 0;
    unsigned            int idx = 0;
    unsigned           int mask = 0;
    unsigned int bytes_per_item = 1;
    unsigned           int bits = 8;
    unsigned       int curr_val = 0;
-   unsigned      int num_added = 0;
    unsigned         int offset = 0;
    cheat_manager_t   *cheat_st = &cheat_manager_state;
    unsigned char         *curr = cheat_st->curr_memory_buf;
+#ifdef HAVE_MENU
+   struct menu_state *menu_st  = menu_state_get_ptr();
+#endif
 
    if (cheat_st->num_matches + cheat_st->size > 100)
    {
@@ -1273,7 +1266,6 @@ int cheat_manager_add_matches(const char *path,
                   runloop_msg_queue_push(msg_hash_to_str(MSG_CHEAT_SEARCH_ADDED_MATCHES_FAIL), 1, 180, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
                   return 0;
                }
-               num_added++;
             }
          }
          else
@@ -1287,7 +1279,6 @@ int cheat_manager_add_matches(const char *path,
                   runloop_msg_queue_push(msg_hash_to_str(MSG_CHEAT_SEARCH_ADDED_MATCHES_FAIL), 1, 180, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
                   return 0;
                }
-               num_added++;
             }
          }
 
@@ -1300,10 +1291,9 @@ int cheat_manager_add_matches(const char *path,
    runloop_msg_queue_push(msg, 1, 180, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
 
 #ifdef HAVE_MENU
-   menu_entries_ctl(MENU_ENTRIES_CTL_SET_REFRESH, &refresh);
-   menu_driver_ctl(RARCH_MENU_CTL_SET_PREVENT_POPULATE, NULL);
+   menu_st->flags                 |=  MENU_ST_FLAG_ENTRIES_NEED_REFRESH
+                                   |  MENU_ST_FLAG_PREVENT_POPULATE;
 #endif
-
    return 0;
 }
 
@@ -1761,14 +1751,15 @@ int cheat_manager_copy_match(rarch_setting_t *setting, size_t idx, bool wraparou
 
 int cheat_manager_delete_match(rarch_setting_t *setting, size_t idx, bool wraparound)
 {
-   bool              refresh = false;
-   cheat_manager_t *cheat_st = &cheat_manager_state;
-
+   cheat_manager_t *cheat_st  = &cheat_manager_state;
+#ifdef HAVE_MENU
+   struct menu_state *menu_st = menu_state_get_ptr();
+#endif
    cheat_manager_match_action(CHEAT_MATCH_ACTION_TYPE_DELETE,
          cheat_st->match_idx, NULL, NULL, NULL, NULL);
 #ifdef HAVE_MENU
-   menu_entries_ctl(MENU_ENTRIES_CTL_SET_REFRESH, &refresh);
-   menu_driver_ctl(RARCH_MENU_CTL_SET_PREVENT_POPULATE, NULL);
+   menu_st->flags                 |=  MENU_ST_FLAG_ENTRIES_NEED_REFRESH
+                                   |  MENU_ST_FLAG_PREVENT_POPULATE;
 #endif
    return 0;
 }
