@@ -8,7 +8,7 @@
  * - Allow changing IP address and port in runtime
  * - Input recording / Combos
  * - Enable test input loading from menu
- * - Visualization of keyboard and aux inputs (gyro, accelero, light)
+ * - Visualization of aux inputs (gyro, accelero, light)
 */
 
 #include <stdio.h>
@@ -50,13 +50,16 @@
 
 #define DESC_OFFSET(desc, port, index, id) ( \
    port * ((desc)->index_max - (desc)->index_min + 1) * ((desc)->id_max - (desc)->id_min + 1) + \
-   index * ((desc)->id_max - (desc)->id_min + 1) + \
+   (index - (desc)->index_min) * ((desc)->id_max - (desc)->id_min + 1) + \
    id \
 )
 
 #define MAX_TEST_STEPS 200
 #define INITIAL_FRAMES 60*5
 #define ONE_TEST_STEP_FRAMES 60*5
+#define KEYBOARD_OFFSET 1000
+#define NETRETROPAD_SCREEN_PAD 0
+#define NETRETROPAD_SCREEN_KEYBOARD 1
 
 struct descriptor {
    int device;
@@ -77,6 +80,9 @@ struct remote_joypad_message {
    uint16_t state;
 };
 
+static bool keyboard_state[RETROK_LAST];
+static bool keyboard_state_validated[RETROK_LAST];
+
 static int s;
 static int port;
 static char server[64];
@@ -114,11 +120,24 @@ static struct descriptor analog = {
    .id_max = RETRO_DEVICE_ID_ANALOG_Y
 };
 
+static struct descriptor analog_button = {
+   .device = RETRO_DEVICE_ANALOG,
+   .port_min = 0,
+   .port_max = 0,
+   .index_min = RETRO_DEVICE_INDEX_ANALOG_BUTTON,
+   .index_max = RETRO_DEVICE_INDEX_ANALOG_BUTTON,
+   .id_min = RETRO_DEVICE_ID_JOYPAD_B,
+   .id_max = RETRO_DEVICE_ID_JOYPAD_R3
+};
+
 static struct descriptor *descriptors[] = {
    &joypad,
-   &analog
+   &analog,
+   &analog_button
 };
 
+static uint16_t analog_item_colors[32];
+
 static uint16_t combo_def[] =
 {
    1 << RETRO_DEVICE_ID_JOYPAD_UP    | 1 << RETRO_DEVICE_ID_JOYPAD_LEFT,  /* D-pad diagonals */
@@ -137,6 +156,8 @@ static uint16_t combo_def[] =
    1 << RETRO_DEVICE_ID_JOYPAD_L2    | 1 << RETRO_DEVICE_ID_JOYPAD_R2
 };
 
+static unsigned current_screen = NETRETROPAD_SCREEN_PAD;
+
 typedef struct
 {
    unsigned expected_button;
@@ -153,7 +174,7 @@ static unsigned last_test_step        = MAX_TEST_STEPS + 1;
 static uint32_t input_state_validated = 0;
 static uint32_t combo_state_validated = 0;
 static bool     dump_state_blocked    = false;
-
+static bool     hide_analog_mismatch  = true;
 /************************************/
 /* JSON Helpers for test input file */
 /************************************/
@@ -338,6 +359,56 @@ end:
 /* Test input file handling end */
 /********************************/
 
+static void draw_background(void)
+{
+   if (frame_buf)
+   {
+      unsigned rle, runs, count;
+      /* Body is 255 * 142 within the 320 * 240 frame */
+      uint16_t *pixel = frame_buf + 49 * 320 + 32;
+
+      if (current_screen == NETRETROPAD_SCREEN_PAD)
+         for (rle = 0; rle < sizeof(body); )
+         {
+            uint16_t color = 0;
+
+            for (runs = body[rle++]; runs > 0; runs--)
+            {
+               for (count = body[rle++]; count > 0; count--)
+                  *pixel++ = color;
+
+               color = 0x4208 - color;
+            }
+
+            pixel += 65;
+         }
+      else if (current_screen == NETRETROPAD_SCREEN_KEYBOARD)
+         for (rle = 0; rle < sizeof(keyboard_body); )
+         {
+            uint16_t color = 0;
+
+            for (runs = keyboard_body[rle++]; runs > 0; runs--)
+            {
+               for (count = keyboard_body[rle++]; count > 0; count--)
+                  *pixel++ = color;
+
+               color = 0x4208 - color;
+            }
+
+            pixel += 65;
+         }
+   }
+}
+
+static void flip_screen(void)
+{
+   if      (current_screen == NETRETROPAD_SCREEN_PAD)
+      current_screen = NETRETROPAD_SCREEN_KEYBOARD;
+   else if (current_screen == NETRETROPAD_SCREEN_KEYBOARD)
+      current_screen = NETRETROPAD_SCREEN_PAD;
+   draw_background();
+}
+
 void NETRETROPAD_CORE_PREFIX(retro_init)(void)
 {
    unsigned i;
@@ -345,26 +416,7 @@ void NETRETROPAD_CORE_PREFIX(retro_init)(void)
    dump_state_blocked = false;
    frame_buf = (uint16_t*)calloc(320 * 240, sizeof(uint16_t));
 
-   if (frame_buf)
-   {
-      unsigned rle, runs, count;
-      uint16_t *pixel = frame_buf + 49 * 320 + 32;
-
-      for (rle = 0; rle < sizeof(body); )
-      {
-         uint16_t color = 0;
-
-         for (runs = body[rle++]; runs > 0; runs--)
-         {
-            for (count = body[rle++]; count > 0; count--)
-               *pixel++ = color;
-
-            color = 0x4208 - color;
-         }
-
-         pixel += 65;
-      }
-   }
+   draw_background();
 
    /* Allocate descriptor values */
    for (i = 0; i < ARRAY_SIZE(descriptors); i++)
@@ -430,6 +482,39 @@ void NETRETROPAD_CORE_PREFIX(retro_get_system_av_info)(
    info->geometry.aspect_ratio = 4.0 / 3.0;
 }
 
+static void NETRETROPAD_CORE_PREFIX(update_keyboard_cb)(bool down, unsigned keycode,
+                               uint32_t character, uint16_t key_modifiers)
+{
+   struct retro_message message;
+   char buf[255];
+
+   if (keycode < RETROK_LAST)
+   {
+      keyboard_state[keycode] = down ? true : false;
+      if (down && ((keycode == RETROK_a && keyboard_state[RETROK_b]) || (keycode == RETROK_b && keyboard_state[RETROK_a])))
+         flip_screen();
+      /* Message for the keypresses not shown as actual keys, just placeholder blocks */
+      if ((keycode ==   0) ||
+          (keycode ==  12) ||
+          (keycode >=  33  && keycode < 39)  ||
+          (keycode >=  40  && keycode < 44)  ||
+          (keycode ==  58) ||
+          (keycode ==  60) ||
+          (keycode >=  62  && keycode < 65)  ||
+          (keycode >=  94  && keycode < 96)  ||
+          (keycode >= 123  && keycode < 127) ||
+          (keycode == 272) ||
+          (keycode >= 294  && keycode < 297) ||
+          (keycode >= 309  && keycode < RETROK_LAST))
+      {
+         snprintf(buf, sizeof(buf), "Key pressed: %d",keycode);
+            message.msg = buf;
+            message.frames = 60;
+            NETRETROPAD_CORE_PREFIX(environ_cb)(RETRO_ENVIRONMENT_SET_MESSAGE, &message);
+      }
+   }
+}
+
 static void retropad_update_input(void)
 {
    unsigned i;
@@ -477,7 +562,11 @@ static void retropad_update_input(void)
                /* Update state */
                desc->value[offset] = state;
 
-               /* Attempt to send updated state */
+               /* Do not send analog button state - RA side is not prepared to receive it */
+               if (i>1)
+                  continue;
+
+               /* Otherwise, attempt to send updated state */
                msg.port            = port;
                msg.device          = desc->device;
                msg.index           = index;
@@ -492,6 +581,35 @@ static void retropad_update_input(void)
    }
 }
 
+static void netretropad_open_udp_socket(void)
+{
+   socket_target_t in_target;
+
+   if (s && s != SOCKET_ERROR)
+      socket_close(s);
+
+   s = socket_create(
+         "retropad",
+         SOCKET_DOMAIN_INET,
+         SOCKET_TYPE_DATAGRAM,
+         SOCKET_PROTOCOL_UDP);
+
+   if (s == SOCKET_ERROR)
+      NETRETROPAD_CORE_PREFIX(log_cb)(RETRO_LOG_INFO, "socket failed");
+
+   /* setup address structure */
+   memset((char *) &si_other, 0, sizeof(si_other));
+
+   in_target.port   = port;
+   in_target.server = server;
+   in_target.domain = SOCKET_DOMAIN_INET;
+
+   socket_set_target(&si_other, &in_target);
+
+   NETRETROPAD_CORE_PREFIX(log_cb)(RETRO_LOG_INFO, "Server IP Address: %s\n" , server);
+
+}
+
 void NETRETROPAD_CORE_PREFIX(retro_set_environment)(retro_environment_t cb)
 {
    static const struct retro_variable vars[] = {
@@ -500,10 +618,13 @@ void NETRETROPAD_CORE_PREFIX(retro_set_environment)(retro_environment_t cb)
       { "net_retropad_ip_octet2", "IP address part 2; 0|1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|46|47|48|49|50|51|52|53|54|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|83|84|85|86|87|88|89|90|91|92|93|94|95|96|97|98|99|100|101|102|103|104|105|106|107|108|109|110|111|112|113|114|115|116|117|118|119|120|121|122|123|124|125|126|127|128|129|130|131|132|133|134|135|136|137|138|139|140|141|142|143|144|145|146|147|148|149|150|151|152|153|154|155|156|157|158|159|160|161|162|163|164|165|166|167|168|169|170|171|172|173|174|175|176|177|178|179|180|181|182|183|184|185|186|187|188|189|190|191|192|193|194|195|196|197|198|199|200|201|202|203|204|205|206|207|208|209|210|211|212|213|214|215|216|217|218|219|220|221|222|223|224|225|226|227|228|229|230|231|232|233|234|235|236|237|238|239|240|241|242|243|244|245|246|247|248|249|250|251|252|253|254|255" },
       { "net_retropad_ip_octet3", "IP address part 3; 0|1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|46|47|48|49|50|51|52|53|54|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|83|84|85|86|87|88|89|90|91|92|93|94|95|96|97|98|99|100|101|102|103|104|105|106|107|108|109|110|111|112|113|114|115|116|117|118|119|120|121|122|123|124|125|126|127|128|129|130|131|132|133|134|135|136|137|138|139|140|141|142|143|144|145|146|147|148|149|150|151|152|153|154|155|156|157|158|159|160|161|162|163|164|165|166|167|168|169|170|171|172|173|174|175|176|177|178|179|180|181|182|183|184|185|186|187|188|189|190|191|192|193|194|195|196|197|198|199|200|201|202|203|204|205|206|207|208|209|210|211|212|213|214|215|216|217|218|219|220|221|222|223|224|225|226|227|228|229|230|231|232|233|234|235|236|237|238|239|240|241|242|243|244|245|246|247|248|249|250|251|252|253|254|255" },
       { "net_retropad_ip_octet4", "IP address part 4; 0|1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|46|47|48|49|50|51|52|53|54|55|56|57|58|59|60|61|62|63|64|65|66|67|68|69|70|71|72|73|74|75|76|77|78|79|80|81|82|83|84|85|86|87|88|89|90|91|92|93|94|95|96|97|98|99|100|101|102|103|104|105|106|107|108|109|110|111|112|113|114|115|116|117|118|119|120|121|122|123|124|125|126|127|128|129|130|131|132|133|134|135|136|137|138|139|140|141|142|143|144|145|146|147|148|149|150|151|152|153|154|155|156|157|158|159|160|161|162|163|164|165|166|167|168|169|170|171|172|173|174|175|176|177|178|179|180|181|182|183|184|185|186|187|188|189|190|191|192|193|194|195|196|197|198|199|200|201|202|203|204|205|206|207|208|209|210|211|212|213|214|215|216|217|218|219|220|221|222|223|224|225|226|227|228|229|230|231|232|233|234|235|236|237|238|239|240|241|242|243|244|245|246|247|248|249|250|251|252|253|254|255" },
-
+      { "net_retropad_screen", "Start screen; Retropad|Keyboard tester" },
+      { "net_retropad_hide_analog_mismatch", "Hide mismatching analog button inputs; True|False" },
       { NULL, NULL },
    };
    enum retro_pixel_format fmt = RETRO_PIXEL_FORMAT_RGB565;
+   struct retro_keyboard_callback kcb = { NETRETROPAD_CORE_PREFIX(update_keyboard_cb) };
+
    cb(RETRO_ENVIRONMENT_SET_VARIABLES, (void*)vars);
 
    NETRETROPAD_CORE_PREFIX(environ_cb) = cb;
@@ -514,25 +635,42 @@ void NETRETROPAD_CORE_PREFIX(retro_set_environment)(retro_environment_t cb)
 
    if (cb(RETRO_ENVIRONMENT_GET_LOG_INTERFACE, &logger))
       NETRETROPAD_CORE_PREFIX(log_cb) = logger.log;
+
+   NETRETROPAD_CORE_PREFIX(environ_cb)(RETRO_ENVIRONMENT_SET_KEYBOARD_CALLBACK, &kcb);
+
 }
 
 static void netretropad_check_variables(void)
 {
-   struct retro_variable var, var2, var3, var4, port_var;
-   var.key      = "net_retropad_ip_octet1";
-   var2.key     = "net_retropad_ip_octet2";
-   var3.key     = "net_retropad_ip_octet3";
-   var4.key     = "net_retropad_ip_octet4";
-   port_var.key = "net_retropad_port";
+   struct retro_variable var, var2, var3, var4, port_var, screen_var, hide_a_var;
+   var.key        = "net_retropad_ip_octet1";
+   var2.key       = "net_retropad_ip_octet2";
+   var3.key       = "net_retropad_ip_octet3";
+   var4.key       = "net_retropad_ip_octet4";
+   port_var.key   = "net_retropad_port";
+   screen_var.key = "net_retropad_screen";
+   hide_a_var.key = "net_retropad_hide_analog_mismatch";
 
    NETRETROPAD_CORE_PREFIX(environ_cb)(RETRO_ENVIRONMENT_GET_VARIABLE, &var);
    NETRETROPAD_CORE_PREFIX(environ_cb)(RETRO_ENVIRONMENT_GET_VARIABLE, &var2);
    NETRETROPAD_CORE_PREFIX(environ_cb)(RETRO_ENVIRONMENT_GET_VARIABLE, &var3);
    NETRETROPAD_CORE_PREFIX(environ_cb)(RETRO_ENVIRONMENT_GET_VARIABLE, &var4);
    NETRETROPAD_CORE_PREFIX(environ_cb)(RETRO_ENVIRONMENT_GET_VARIABLE, &port_var);
+   NETRETROPAD_CORE_PREFIX(environ_cb)(RETRO_ENVIRONMENT_GET_VARIABLE, &screen_var);
+   NETRETROPAD_CORE_PREFIX(environ_cb)(RETRO_ENVIRONMENT_GET_VARIABLE, &hide_a_var);
 
    snprintf(server, sizeof(server), "%s.%s.%s.%s", var.value, var2.value, var3.value, var4.value);
    port = atoi(port_var.value);
+
+   if (screen_var.value &&
+       ((current_screen == NETRETROPAD_SCREEN_PAD && strstr(screen_var.value,"Keyboard")) ||
+        (current_screen == NETRETROPAD_SCREEN_KEYBOARD && strstr(screen_var.value,"Retropad"))))
+      flip_screen();
+   if (hide_a_var.value && strstr(hide_a_var.value,"True"))
+      hide_analog_mismatch = true;
+   else
+      hide_analog_mismatch = false;
+
 }
 
 void NETRETROPAD_CORE_PREFIX(retro_set_audio_sample)(retro_audio_sample_t cb)
@@ -562,7 +700,10 @@ void NETRETROPAD_CORE_PREFIX(retro_set_video_refresh)(retro_video_refresh_t cb)
 }
 
 void NETRETROPAD_CORE_PREFIX(retro_reset)(void)
-{}
+{
+   netretropad_check_variables();
+   netretropad_open_udp_socket();
+}
 
 void NETRETROPAD_CORE_PREFIX(retro_run)(void)
 {
@@ -582,31 +723,60 @@ void NETRETROPAD_CORE_PREFIX(retro_run)(void)
       int offset = DESC_OFFSET(&joypad, 0, 0, i);
       if (joypad.value[offset])
          input_state |= 1 << i;
+
+      /* Construct a red gradient representation for analog buttons */
+      offset = DESC_OFFSET(&analog_button, 0, RETRO_DEVICE_INDEX_ANALOG_BUTTON, i);
+      analog_item_colors[i] = (uint16_t)((int16_t)analog_button.value[offset]/1638) << 11;
    }
 
    for (i = analog.id_min; i <= analog.id_max; i++)
    {
       /* bitmap: x-- x- x+ x++ y-- y- y+ y++*/
-      /* default analog deadzone: 0.0 - increased for convenience, default analog threshold: 0.5 */
+      /* default analog deadzone: 0.0 - increased for convenience to 0.1, default analog threshold: 0.5 */
+      /* Red gradient also calculated */
       int offset = DESC_OFFSET(&analog, 0, RETRO_DEVICE_INDEX_ANALOG_LEFT, i);
-      if (     (int16_t)analog.value[offset] < -32766/2)
+      if (     (int16_t)analog.value[offset] < -32768/2)
+      {
          input_state |= 1 << (16 + i*8 + 0);
+         analog_item_colors[  16 + i*8 + 0] = (uint16_t)((-1*((int16_t)analog.value[offset])-32768/2) /528) << 11;
+      }
       else if ((int16_t)analog.value[offset] < -3276)
+      {
          input_state |= 1 << (16 + i*8 + 1);
+         analog_item_colors[  16 + i*8 + 1] = (uint16_t)((-1*((int16_t)analog.value[offset])        ) /528) << 11;
+      }
       else if ((int16_t)analog.value[offset] > 32768/2)
+      {
          input_state |= 1 << (16 + i*8 + 3);
+         analog_item_colors[  16 + i*8 + 3] = (uint16_t)((   ((int16_t)analog.value[offset])-32768/2) /528) << 11;
+      }
       else if ((int16_t)analog.value[offset] > 3276)
+      {
          input_state |= 1 << (16 + i*8 + 2);
+         analog_item_colors[  16 + i*8 + 2] = (uint16_t)((   ((int16_t)analog.value[offset])        ) /528) << 11;
+      }
 
       offset = DESC_OFFSET(&analog, 0, RETRO_DEVICE_INDEX_ANALOG_RIGHT, i);
-      if (     (int16_t)analog.value[offset] < -32766/2)
+      if (     (int16_t)analog.value[offset] < -32768/2)
+      {
          input_state |= 1 << (16 + i*8 + 4);
+         analog_item_colors[  16 + i*8 + 4] = (uint16_t)((-1*((int16_t)analog.value[offset])-32768/2) /528) << 11;
+      }
       else if ((int16_t)analog.value[offset] < -3276)
+      {
          input_state |= 1 << (16 + i*8 + 5);
+         analog_item_colors[  16 + i*8 + 5] = (uint16_t)((-1*((int16_t)analog.value[offset])        ) /528) << 11;
+      }
       else if ((int16_t)analog.value[offset] > 32768/2)
+      {
          input_state |= 1 << (16 + i*8 + 7);
+         analog_item_colors[  16 + i*8 + 7] = (uint16_t)((   ((int16_t)analog.value[offset])-32768/2) /528) << 11;
+      }
       else if ((int16_t)analog.value[offset] > 3276)
+      {
          input_state |= 1 << (16 + i*8 + 6);
+         analog_item_colors[  16 + i*8 + 6] = (uint16_t)((   ((int16_t)analog.value[offset])        ) /528) << 11;
+      }
    }
 
    /* Input test section start. */
@@ -619,7 +789,7 @@ void NETRETROPAD_CORE_PREFIX(retro_run)(void)
    }
 
 /* Print a log for A+B combination, but only once while those are pressed */
-   if (input_state == ((1 << RETRO_DEVICE_ID_JOYPAD_A | 1 << RETRO_DEVICE_ID_JOYPAD_B) & 0x0000ffff))
+   if (input_state & ((1 << RETRO_DEVICE_ID_JOYPAD_A | 1 << RETRO_DEVICE_ID_JOYPAD_B) & 0x0000ffff))
    {
       if (!dump_state_blocked)
       {
@@ -647,6 +817,9 @@ void NETRETROPAD_CORE_PREFIX(retro_run)(void)
             NETRETROPAD_CORE_PREFIX(log_cb)(RETRO_LOG_INFO,
                "[Remote RetroPad]: Proceeding to test step %d at frame %d, next: %d\n",
                current_test_step,current_frame,next_teststep_frame+INITIAL_FRAMES);
+            if((input_test_steps[current_test_step].expected_button <  KEYBOARD_OFFSET && current_screen == NETRETROPAD_SCREEN_KEYBOARD) ||
+               (input_test_steps[current_test_step].expected_button >= KEYBOARD_OFFSET && current_screen == NETRETROPAD_SCREEN_PAD))
+                  flip_screen();
          }
          else
          {
@@ -671,8 +844,20 @@ void NETRETROPAD_CORE_PREFIX(retro_run)(void)
 
       if (current_test_step < last_test_step)
       {
-         expected_input = 1 << input_test_steps[current_test_step].expected_button;
-         if(input_state & expected_input)
+         bool test_success = false;
+         if (input_test_steps[current_test_step].expected_button < KEYBOARD_OFFSET)
+         {
+            expected_input = 1 << input_test_steps[current_test_step].expected_button;
+            if(input_state & expected_input)
+               test_success = true;
+         }
+         else
+         {
+            expected_input = input_test_steps[current_test_step].expected_button - KEYBOARD_OFFSET;
+            if (expected_input < RETROK_LAST && keyboard_state[expected_input])
+               test_success = true;
+         }
+         if (test_success)
          {
             NETRETROPAD_CORE_PREFIX(log_cb)(RETRO_LOG_INFO,
                "[Remote RetroPad]: Test step %d successful at frame %d\n",
@@ -683,82 +868,124 @@ void NETRETROPAD_CORE_PREFIX(retro_run)(void)
       }
    }
    /* Input test section end. */
-
-   for (rle = 0; rle < sizeof(retropad_buttons); )
+   if (current_screen == NETRETROPAD_SCREEN_PAD)
    {
-      unsigned runs;
-      char      paint = 0;
-
-      for (runs = retropad_buttons[rle++]; runs > 0; runs--)
+      for (rle = 0; rle < sizeof(retropad_buttons); )
       {
-         unsigned button = paint ? 1 << retropad_buttons[rle++] : 0;
+         unsigned runs;
+         char      paint = 0;
 
-         if (paint)
+         for (runs = retropad_buttons[rle++]; runs > 0; runs--)
          {
-            unsigned count;
-            uint16_t color;
-
-            /* Red for active inputs */
-            if (input_state & button)
+            if (paint)
             {
-               color = 0xA000;
-               input_state_validated |= button;
+               unsigned button = 0;
+               unsigned button_analog = 0;
+               unsigned count;
+               uint16_t color;
+
+               /* 0  - 15: buttons, 16 - 31: analog x/y */
+               /* 32 - 47: analog input for same buttons */
+               if (retropad_buttons[rle] < 32)
+                  button        = 1 <<  retropad_buttons[rle];
+               else
+                  button_analog = 1 << (retropad_buttons[rle] - 32);
+
+               /* Red for active inputs */
+               if (input_state & button)
+               {
+                  if(retropad_buttons[rle]<16)
+                     color = 0xA000;
+                  else
+                     /* Gradient for analog axes */
+                     color = analog_item_colors[retropad_buttons[rle]];
+                  input_state_validated |= button;
+               }
+               /* Red gradient for active analog button inputs, from 0 to 0xa000 */
+               else if (button_analog && analog_item_colors[retropad_buttons[rle] - 32])
+               {
+                  color = analog_item_colors[retropad_buttons[rle] - 32];
+               }
+               else if (button_analog && hide_analog_mismatch && input_state & button_analog)
+                  color = 0xA000;
+               else
+               {
+                  /* Light blue for expected input */
+                  if (expected_input & button || expected_input & button_analog)
+                     color = 0x7fff;
+                  /* Light green for already validated input */
+                  else if (input_state_validated & button || input_state_validated & button_analog)
+                     color = 0xbff7;
+                  /* White as default */
+                  else
+                     color = 0xffff;
+               }
+
+               rle++;
+               for (count = retropad_buttons[rle++]; count > 0; count--)
+                  *pixel++ = color;
             }
             else
-            {
-               /* Light blue for expected input */
-               if (expected_input & button)
-                  color = 0x7fff;
-               /* Light green for already validated input */
-               else if (input_state_validated & button )
-                  color = 0xbff7;
-               /* White as default */
-               else
-                  color = 0xffff;
-            }
+               pixel += retropad_buttons[rle++];
 
-            for (count = retropad_buttons[rle++]; count > 0; count--)
-               *pixel++ = color;
+            paint = !paint;
          }
-         else
-            pixel += retropad_buttons[rle++];
 
-         paint = !paint;
+         pixel += 65;
       }
+   }
+   else if (current_screen == NETRETROPAD_SCREEN_KEYBOARD)
+   {
+      for (rle = 0; rle < ARRAY_SIZE(keyboard_buttons); )
+      {
+         unsigned runs;
+         char      paint = 0;
 
-      pixel += 65;
+         for (runs = keyboard_buttons[rle++]; runs > 0; runs--)
+         {
+            if (paint)
+            {
+               unsigned count;
+               uint16_t color;
+
+               /* Same color scheme as for retropad buttons */
+               if (keyboard_state[keyboard_buttons[rle]])
+               {
+                  color = 0xA000;
+                  keyboard_state_validated[keyboard_buttons[rle]] = true;
+               }
+               else
+               {
+                  if (expected_input > 0 && expected_input == keyboard_buttons[rle])
+                     color = 0x7fff;
+                  else if (keyboard_state_validated[keyboard_buttons[rle]])
+                     color = 0xbff7;
+                  else
+                     color = 0xffff;
+               }
+               rle++;
+
+               for (count = keyboard_buttons[rle++]; count > 0; count--)
+                  *pixel++ = color;
+            }
+            else
+               pixel += keyboard_buttons[rle++];
+
+            paint = !paint;
+         }
+
+         pixel += 65;
+      }
    }
 
    NETRETROPAD_CORE_PREFIX(video_cb)(frame_buf, 320, 240, 640);
-
    retro_sleep(4);
 }
 
 bool NETRETROPAD_CORE_PREFIX(retro_load_game)(const struct retro_game_info *info)
 {
-   socket_target_t in_target;
-
    netretropad_check_variables();
-
-   s = socket_create(
-         "retropad",
-         SOCKET_DOMAIN_INET,
-         SOCKET_TYPE_DATAGRAM,
-         SOCKET_PROTOCOL_UDP);
-
-   if (s == SOCKET_ERROR)
-      NETRETROPAD_CORE_PREFIX(log_cb)(RETRO_LOG_INFO, "socket failed");
-
-   /* setup address structure */
-   memset((char *) &si_other, 0, sizeof(si_other));
-
-   in_target.port   = port;
-   in_target.server = server;
-   in_target.domain = SOCKET_DOMAIN_INET;
-
-   socket_set_target(&si_other, &in_target);
-
-   NETRETROPAD_CORE_PREFIX(log_cb)(RETRO_LOG_INFO, "Server IP Address: %s\n" , server);
+   netretropad_open_udp_socket();
 
    /* If a .ratst file is given (only possible via command line),
     * initialize test sequence. */
