@@ -26,6 +26,7 @@
 
 #include <CoreFoundation/CoreFoundation.h>
 #include <CoreFoundation/CFArray.h>
+#import <AVFoundation/AVFoundation.h>
 
 #ifdef HAVE_CONFIG_H
 #include "../../config.h"
@@ -54,6 +55,7 @@
 #include <streams/file_stream.h>
 #include <features/features_cpu.h>
 #include <string/stdstring.h>
+#include <lists/dir_list.h>
 
 #ifdef HAVE_MENU
 #include "../../menu/menu_driver.h"
@@ -410,7 +412,7 @@ static void frontend_darwin_get_env(int *argc, char *argv[],
 #if defined(HAVE_UPDATE_CORES) || defined(HAVE_STEAM)
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CORE], application_data, "cores", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE]));
 #else
-   fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CORE], bundle_path_buf, "modules", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE]));
+   fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CORE], bundle_path_buf, "Frameworks", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE]));
 #endif
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_DATABASE], application_data, "database/rdb", sizeof(g_defaults.dirs[DEFAULT_DIR_DATABASE]));
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CORE_ASSETS], application_data, "downloads", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE_ASSETS]));
@@ -712,36 +714,45 @@ static int frontend_darwin_parse_drive_list(void *data, bool load_content)
    int ret = -1;
 #if TARGET_OS_IPHONE
 #ifdef HAVE_MENU
+   struct string_list *str_list          = NULL;
    file_list_t *list                     = (file_list_t*)data;
-   char bundle_path_buf[PATH_MAX_LENGTH] = {0};
-   char home_dir_buf[PATH_MAX_LENGTH]    = {0};
-   CFBundleRef bundle                    = CFBundleGetMainBundle();
-   enum msg_hash_enums enum_idx          = load_content 
-      ? MENU_ENUM_LABEL_FILE_DETECT_CORE_LIST_PUSH_DIR 
+   enum msg_hash_enums enum_idx          = load_content
+      ? MENU_ENUM_LABEL_FILE_DETECT_CORE_LIST_PUSH_DIR
       : MENU_ENUM_LABEL_FILE_BROWSER_DIRECTORY;
-   CFURLRef bundle_url                   = CFBundleCopyBundleURL(bundle);
-   CFStringRef bundle_path               = CFURLCopyPath(bundle_url);
 
-   CFStringGetCString(bundle_path, bundle_path_buf,
-         sizeof(bundle_path_buf), kCFStringEncodingUTF8);
+   if (list->size == 0)
+      menu_entries_append(list,
+#if TARGET_OS_TV
+            "~/Library/Caches/RetroArch",
+#else
+            "~/Documents/RetroArch",
+#endif
+            msg_hash_to_str(MENU_ENUM_LABEL_FILE_DETECT_CORE_LIST_PUSH_DIR),
+            enum_idx,
+            FILE_TYPE_DIRECTORY, 0, 0, NULL);
 
-   CFSearchPathForDirectoriesInDomains(
-         home_dir_buf, sizeof(home_dir_buf));
+   str_list = string_list_new();
+   // only add / if it's jailbroken
+   dir_list_append(str_list, "/private/var", NULL, true, false, false, false);
+   if (str_list->size > 0)
+      menu_entries_append(list, "/",
+            msg_hash_to_str(MENU_ENUM_LABEL_FILE_DETECT_CORE_LIST_PUSH_DIR),
+            enum_idx,
+            FILE_TYPE_DIRECTORY, 0, 0, NULL);
+   string_list_free(str_list);
 
-   menu_entries_append(list,
-         home_dir_buf,
-         msg_hash_to_str(MENU_ENUM_LABEL_FILE_DETECT_CORE_LIST_PUSH_DIR),
-         enum_idx,
-         FILE_TYPE_DIRECTORY, 0, 0, NULL);
-   menu_entries_append(list, "/",
-         msg_hash_to_str(MENU_ENUM_LABEL_FILE_DETECT_CORE_LIST_PUSH_DIR),
-         enum_idx,
-        FILE_TYPE_DIRECTORY, 0, 0, NULL);
+#if TARGET_OS_IOS
+   if (   filebrowser_get_type() == FILEBROWSER_NONE ||
+          filebrowser_get_type() == FILEBROWSER_SCAN_FILE ||
+          filebrowser_get_type() == FILEBROWSER_SELECT_FILE)
+      menu_entries_append(list,
+                          msg_hash_to_str(MENU_ENUM_LABEL_VALUE_FILE_BROWSER_OPEN_PICKER),
+                          msg_hash_to_str(MENU_ENUM_LABEL_FILE_BROWSER_OPEN_PICKER),
+                          MENU_ENUM_LABEL_FILE_BROWSER_OPEN_PICKER,
+                          MENU_SETTING_ACTION, 0, 0, NULL);
+#endif
 
    ret = 0;
-
-   CFRelease(bundle_path);
-   CFRelease(bundle_url);
 #endif
 #endif
    return ret;
@@ -760,7 +771,7 @@ static uint64_t frontend_darwin_get_total_mem(void)
     task_vm_info_data_t vmInfo;
     mach_msg_type_number_t count = TASK_VM_INFO_COUNT;
     if (task_info(mach_task_self(), TASK_VM_INFO, (task_info_t) &vmInfo, &count) == KERN_SUCCESS)
-       return vmInfo.resident_size_peak;
+       return vmInfo.phys_footprint + vmInfo.limit_bytes_remaining;
 #endif
     return 0;
 }
@@ -787,7 +798,7 @@ static uint64_t frontend_darwin_get_free_mem(void)
     task_vm_info_data_t vmInfo;
     mach_msg_type_number_t count = TASK_VM_INFO_COUNT;
     if (task_info(mach_task_self(), TASK_VM_INFO, (task_info_t) &vmInfo, &count) == KERN_SUCCESS)
-        return vmInfo.resident_size_peak - vmInfo.resident_size;
+        return vmInfo.limit_bytes_remaining;
 #endif
     return 0;
 }
@@ -799,7 +810,18 @@ static const char* frontend_darwin_get_cpu_model_name(void)
    return darwin_cpu_model_name;
 }
 
-#if (defined(OSX) && (MAC_OS_X_VERSION_MAX_ALLOWED >= 101200))
+static enum retro_language frontend_darwin_get_user_language(void)
+{
+   char s[128];
+   CFArrayRef langs = CFLocaleCopyPreferredLanguages();
+   CFStringRef langCode = CFArrayGetValueAtIndex(langs, 0);
+   CFStringGetCString(langCode, s, sizeof(s), kCFStringEncodingUTF8);
+   /* iOS and OS X only support the language ID syntax consisting of a language designator and optional region or script designator. */
+   string_replace_all_chars(s, '-', '_');
+   return retroarch_get_language_from_iso(s);
+}
+
+#if defined(OSX)
 static char* accessibility_mac_language_code(const char* language)
 {
    if (string_is_equal(language,"en"))
@@ -873,16 +895,13 @@ static bool is_narrator_running_macos(void)
 }
 
 static bool accessibility_speak_macos(int speed,
-      const char* speak_text, int priority, const char* voice)
+      const char* speak_text, int priority)
 {
    int pid;
+   const char *voice      = get_user_language_iso639_1(false);
    char* language_speaker = accessibility_mac_language_code(voice);
    char* speeds[10]       = {"80",  "100", "125", "150", "170", "210",
                              "260", "310", "380", "450"};
-   if (speed < 1)
-      speed               = 1;
-   else if (speed > 10)
-      speed               = 10;
 
    if (priority < 10 && speak_pid > 0)
    {
@@ -932,8 +951,60 @@ static bool accessibility_speak_macos(int speed,
    }
    return true;
 }
+
 #endif
 
+static bool frontend_darwin_is_narrator_running(void)
+{
+   if (@available(macOS 10.14, iOS 7, tvOS 9, *))
+      return true;
+#if OSX
+   return is_narrator_running_macos();
+#else
+   return false;
+#endif
+}
+
+static bool frontend_darwin_accessibility_speak(int speed,
+      const char* speak_text, int priority)
+{
+   if (speed < 1)
+      speed               = 1;
+   else if (speed > 10)
+      speed               = 10;
+
+   if (@available(macOS 10.14, iOS 7, tvOS 9, *))
+   {
+      static dispatch_once_t once;
+      static AVSpeechSynthesizer *synth;
+      dispatch_once(&once, ^{
+         synth = [[AVSpeechSynthesizer alloc] init];
+      });
+      if ([synth isSpeaking])
+      {
+         if (priority < 10)
+            return true;
+         else
+            [synth stopSpeakingAtBoundary:AVSpeechBoundaryImmediate];
+      }
+
+      AVSpeechUtterance *utterance = [AVSpeechUtterance speechUtteranceWithString:[NSString stringWithUTF8String:speak_text]];
+      if (!utterance)
+         return false;
+      utterance.rate = (float)speed / 10.0f;
+      const char *language = get_user_language_iso639_1(false);
+      utterance.voice = [AVSpeechSynthesisVoice voiceWithLanguage:[NSString stringWithUTF8String:language]];
+      [synth speakUtterance:utterance];
+      return true;
+   }
+
+#if defined(OSX)
+   return accessibility_speak_macos(speed, speak_text, priority);
+#else
+   return false;
+#endif
+}
+
 frontend_ctx_driver_t frontend_ctx_darwin = {
    frontend_darwin_get_env,         /* get_env */
    NULL,                            /* init */
@@ -964,14 +1035,9 @@ frontend_ctx_driver_t frontend_ctx_darwin = {
    NULL,                            /* check_for_path_changes */
    NULL,                            /* set_sustained_performance_mode */
    frontend_darwin_get_cpu_model_name, /* get_cpu_model_name */
-   NULL,                            /* get_user_language   */
-#if (defined(OSX) && (MAC_OS_X_VERSION_MAX_ALLOWED >= 101200))
-   is_narrator_running_macos,       /* is_narrator_running */
-   accessibility_speak_macos,       /* accessibility_speak */
-#else
-   NULL,                            /* is_narrator_running */
-   NULL,                            /* accessibility_speak */
-#endif
+   frontend_darwin_get_user_language, /* get_user_language   */
+   frontend_darwin_is_narrator_running, /* is_narrator_running */
+   frontend_darwin_accessibility_speak, /* accessibility_speak */
    NULL,                            /* set_gamemode        */
    "darwin",                        /* ident               */
    NULL                             /* get_video_driver    */
