@@ -49,11 +49,11 @@
 #include <string/stdstring.h>
 
 #include "../frontend_driver.h"
-#include "../../verbosity.h"
 #include "../../defaults.h"
+#include "../../file_path_special.h"
 #include "../../paths.h"
 #include "../../retroarch.h"
-#include "../../file_path_special.h"
+#include "../../verbosity.h"
 
 #ifndef IS_SALAMANDER
 #ifdef HAVE_MENU
@@ -67,7 +67,7 @@
 
 #ifdef HAVE_LIBNX
 #define SD_PREFIX
-#include "../../gfx/common/switch_common.h"
+#include "../../gfx/common/switch_defines.h"
 #else
 #define SD_PREFIX "/sd"
 #endif
@@ -171,9 +171,11 @@ static void get_first_valid_core(char *path_return, size_t len)
             break;
          if (strlen(ent->d_name) > strlen(extension) && !strcmp(ent->d_name + strlen(ent->d_name) - strlen(extension), extension))
          {
-            strlcpy(path_return, SD_PREFIX "/retroarch/cores", len);
-            strlcat(path_return, "/", len);
-            strlcat(path_return, ent->d_name, len);
+            size_t _len = strlcpy(path_return, SD_PREFIX "/retroarch/cores", len);
+            _len += strlcpy(path_return + _len,
+                  "/",
+                  len           - _len);
+            strlcpy(path_return + _len, ent->d_name, len - _len);
             break;
          }
       }
@@ -245,12 +247,10 @@ static void frontend_switch_get_env(
                       "cheats", sizeof(g_defaults.dirs[DEFAULT_DIR_CHEATS]));
 
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_OVERLAY], g_defaults.dirs[DEFAULT_DIR_PORT],
-                      "overlay", sizeof(g_defaults.dirs[DEFAULT_DIR_OVERLAY]));
+                      "overlays", sizeof(g_defaults.dirs[DEFAULT_DIR_OVERLAY]));
 
-#ifdef HAVE_VIDEO_LAYOUT
-   fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_VIDEO_LAYOUT], g_defaults.dirs[DEFAULT_DIR_PORT],
-                      "layouts", sizeof(g_defaults.dirs[DEFAULT_DIR_VIDEO_LAYOUT]));
-#endif
+   fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_OSK_OVERLAY], g_defaults.dirs[DEFAULT_DIR_PORT],
+                      "overlays/keyboards", sizeof(g_defaults.dirs[DEFAULT_DIR_OSK_OVERLAY]));
 
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CORE_ASSETS], g_defaults.dirs[DEFAULT_DIR_PORT],
                       "downloads", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE_ASSETS]));
@@ -328,19 +328,16 @@ static void frontend_switch_exec(const char *path, bool should_load_game)
          const char *content = path_get(RARCH_PATH_CONTENT);
 #ifdef HAVE_NETWORKING
          char *arg_data[NETPLAY_FORK_MAX_ARGS];
-
          if (netplay_driver_ctl(RARCH_NETPLAY_CTL_GET_FORK_ARGS,
                (void*)arg_data))
          {
             char buf[PATH_MAX];
             char **arg = arg_data;
-
             do
             {
                snprintf(buf, sizeof(buf), " \"%s\"", *arg);
                strlcat(args, buf, sizeof(args));
-            }
-            while (*(++arg));
+            } while (*(++arg));
          }
          else
 #endif
