@@ -21,6 +21,12 @@
 
 #include "../../input/common/wayland_common.h"
 
+/* Icon is 16x15 scaled by 16 */
+#define SPLASH_WINDOW_WIDTH 240
+#define SPLASH_WINDOW_HEIGHT 256
+
+#define WAYLAND_APP_ID "org.libretro.RetroArch"
+
 typedef struct toplevel_listener
 {
 #ifdef HAVE_LIBDECOR_H
