@@ -66,6 +66,7 @@ struct gfx_widget_leaderboard_display_state
    unsigned challenge_count;
    uint16_t char_width[CHEEVO_LBOARD_LAST_FIXED_CHAR - CHEEVO_LBOARD_FIRST_FIXED_CHAR + 1];
    uint16_t fixed_char_width;
+   uint16_t loading;
    bool disconnected;
 };
 
@@ -115,6 +116,7 @@ static void gfx_widget_leaderboard_display_frame(void* data, void* userdata)
    if (state->tracker_count == 0 &&
        state->challenge_count == 0 &&
        state->progress_tracker.show_until == 0 &&
+       !state->loading &&
        !state->disconnected)
       return;
 
@@ -342,9 +344,10 @@ static void gfx_widget_leaderboard_display_frame(void* data, void* userdata)
          }
       }
 
-      if (state->disconnected)
+      if (state->disconnected || state->loading)
       {
-         const char* disconnected_text = "! RA !";
+         char loading_buffer[8] = "RA ...";
+         const char* disconnected_text = state->disconnected ? "! RA !" : loading_buffer;
          const unsigned disconnect_widget_width = font_driver_get_message_width(
             state->dispwidget_ptr->gfx_widget_fonts.msg_queue.font,
             disconnected_text, 0, 1) + CHEEVO_LBOARD_DISPLAY_PADDING * 2;
@@ -353,6 +356,13 @@ static void gfx_widget_leaderboard_display_frame(void* data, void* userdata)
          x = video_width - disconnect_widget_width - spacing;
          y -= disconnect_widget_height + spacing;
 
+         if (state->loading) {
+            const uint16_t loading_shift = 5;
+            loading_buffer[((state->loading - 1) >> loading_shift) + 3] = '\0';
+            state->loading &= (1 << (loading_shift + 2)) - 1;
+            ++state->loading;
+         }
+
          /* Backdrop */
          gfx_display_draw_quad(
             p_disp,
@@ -586,6 +596,12 @@ void gfx_widget_set_cheevos_disconnect(bool value)
    state->disconnected = value;
 }
 
+void gfx_widget_set_cheevos_set_loading(bool value)
+{
+   gfx_widget_leaderboard_display_state_t* state = &p_w_leaderboard_display_st;
+   state->loading = value ? 1 : 0;
+}
+
 
 const gfx_widget_t gfx_widget_leaderboard_display = {
    &gfx_widget_leaderboard_display_init,
