@@ -22,6 +22,7 @@
 
 #include <AvailabilityMacros.h>
 
+#include "../input_driver.h"
 #include "../../tasks/tasks_internal.h"
 
 #import <GameController/GameController.h>
@@ -30,6 +31,9 @@
 #ifndef MAX_MFI_CONTROLLERS
 #define MAX_MFI_CONTROLLERS 4
 #endif
+#ifndef MAX_MFI_AXES
+#define MAX_MFI_AXES 6
+#endif
 
 #if TARGET_OS_IOS
 #include "../../configuration.h"
@@ -48,9 +52,10 @@ enum
 
 /* TODO/FIXME - static globals */
 static uint32_t mfi_buttons[MAX_USERS];
-static int16_t  mfi_axes[MAX_USERS][4];
+static int16_t  mfi_axes[MAX_USERS][MAX_MFI_AXES];
 static uint32_t mfi_controllers[MAX_MFI_CONTROLLERS];
 static MFIRumbleController *mfi_rumblers[MAX_MFI_CONTROLLERS];
+#define MFI_WEAK_RUMBLE 0.3f
 static NSMutableArray *mfiControllers;
 static bool mfi_inited;
 
@@ -67,6 +72,11 @@ static bool apple_gamecontroller_available(void)
     return true;
 }
 
+static bool mfi_controller_is_siri_remote(GCController *controller)
+{
+   return controller.microGamepad && !controller.extendedGamepad && [@"Remote" isEqualToString:controller.vendorName];
+}
+
 static void apple_gamecontroller_joypad_poll_internal(GCController *controller, uint32_t slot)
 {
     uint32_t *buttons        = &mfi_buttons[slot];
@@ -87,7 +97,36 @@ static void apple_gamecontroller_joypad_poll_internal(GCController *controller,
     }
     memset(mfi_axes[slot], 0, sizeof(mfi_axes[0]));
 
-    if (controller.extendedGamepad)
+    if (@available(macOS 11, iOS 14, tvOS 14, *))
+    {
+        GCPhysicalInputProfile *profile = controller.physicalInputProfile;
+
+        *buttons |= [[profile.dpads[GCInputDirectionPad] up] isPressed]       ? (1 << RETRO_DEVICE_ID_JOYPAD_UP)     : 0;
+        *buttons |= [[profile.dpads[GCInputDirectionPad] down] isPressed]     ? (1 << RETRO_DEVICE_ID_JOYPAD_DOWN)   : 0;
+        *buttons |= [[profile.dpads[GCInputDirectionPad] left] isPressed]     ? (1 << RETRO_DEVICE_ID_JOYPAD_LEFT)   : 0;
+        *buttons |= [[profile.dpads[GCInputDirectionPad] right] isPressed]    ? (1 << RETRO_DEVICE_ID_JOYPAD_RIGHT)  : 0;
+        *buttons |= [profile.buttons[GCInputButtonA] isPressed]               ? (1 << RETRO_DEVICE_ID_JOYPAD_B)      : 0;
+        *buttons |= [profile.buttons[GCInputButtonB] isPressed]               ? (1 << RETRO_DEVICE_ID_JOYPAD_A)      : 0;
+        *buttons |= [profile.buttons[GCInputButtonX] isPressed]               ? (1 << RETRO_DEVICE_ID_JOYPAD_Y)      : 0;
+        *buttons |= [profile.buttons[GCInputButtonY] isPressed]               ? (1 << RETRO_DEVICE_ID_JOYPAD_X)      : 0;
+        *buttons |= [profile.buttons[GCInputLeftShoulder] isPressed]          ? (1 << RETRO_DEVICE_ID_JOYPAD_L)      : 0;
+        *buttons |= [profile.buttons[GCInputRightShoulder] isPressed]         ? (1 << RETRO_DEVICE_ID_JOYPAD_R)      : 0;
+        *buttons |= [profile.buttons[GCInputLeftTrigger] isPressed]           ? (1 << RETRO_DEVICE_ID_JOYPAD_L2)     : 0;
+        *buttons |= [profile.buttons[GCInputRightTrigger] isPressed]          ? (1 << RETRO_DEVICE_ID_JOYPAD_R2)     : 0;
+        *buttons |= [profile.buttons[GCInputLeftThumbstickButton] isPressed]  ? (1 << RETRO_DEVICE_ID_JOYPAD_L3)     : 0;
+        *buttons |= [profile.buttons[GCInputRightThumbstickButton] isPressed] ? (1 << RETRO_DEVICE_ID_JOYPAD_R3)     : 0;
+        *buttons |= [profile.buttons[GCInputButtonOptions] isPressed]         ? (1 << RETRO_DEVICE_ID_JOYPAD_SELECT) : 0;
+        *buttons |= [profile.buttons[GCInputButtonMenu] isPressed]            ? (1 << RETRO_DEVICE_ID_JOYPAD_START)  : 0;
+        *buttons |= [profile.buttons[GCInputButtonHome] isPressed]            ? (1 << RARCH_FIRST_CUSTOM_BIND)       : 0;
+
+        mfi_axes[slot][0] = [[profile.dpads[GCInputLeftThumbstick] xAxis] value]  * 32767.0f;
+        mfi_axes[slot][1] = [[profile.dpads[GCInputLeftThumbstick] yAxis] value]  * 32767.0f;
+        mfi_axes[slot][2] = [[profile.dpads[GCInputRightThumbstick] xAxis] value] * 32767.0f;
+        mfi_axes[slot][3] = [[profile.dpads[GCInputRightThumbstick] yAxis] value] * 32767.0f;
+        mfi_axes[slot][4] = [profile.buttons[GCInputLeftTrigger] value]           * 32767.0f;
+        mfi_axes[slot][5] = [profile.buttons[GCInputRightTrigger] value]          * 32767.0f;
+    }
+    else if (controller.extendedGamepad)
     {
         GCExtendedGamepad *gp = (GCExtendedGamepad *)controller.extendedGamepad;
 
@@ -114,27 +153,29 @@ static void apple_gamecontroller_joypad_poll_internal(GCController *controller,
 #if OSX || __IPHONE_OS_VERSION_MAX_ALLOWED >= 130000 || __TV_OS_VERSION_MAX_ALLOWED >= 130000
         if (@available(iOS 13, tvOS 13, macOS 10.15, *))
         {
-            /* Support "Options" button present in PS4 / XBox One controllers */
             *buttons             |= gp.buttonOptions.pressed ? (1 << RETRO_DEVICE_ID_JOYPAD_SELECT) : 0;
+            *buttons             |= gp.buttonMenu.pressed    ? (1 << RETRO_DEVICE_ID_JOYPAD_START)  : 0;
             if (@available(iOS 14, tvOS 14, macOS 11, *))
-                *buttons         |= gp.buttonHome.pressed ? (1 << RARCH_FIRST_CUSTOM_BIND) : 0;
-
-            /* Support buttons that aren't supported by older mFi controller via "hotkey" combinations:
-             *
-             * LS + Menu => Select
-             * LT + Menu => L3
-             * RT + Menu => R3
-             */
-            if (gp.buttonMenu.pressed )
+                *buttons         |= gp.buttonHome.pressed    ? (1 << RARCH_FIRST_CUSTOM_BIND)       : 0;
+            else
             {
-                if (gp.leftShoulder.pressed)
-                    *buttons     |= 1 << RETRO_DEVICE_ID_JOYPAD_SELECT;
-                else if (gp.leftTrigger.pressed)
-                    *buttons     |= 1 << RETRO_DEVICE_ID_JOYPAD_L3;
-                else if (gp.rightTrigger.pressed)
-                    *buttons     |= 1 << RETRO_DEVICE_ID_JOYPAD_R3;
-                else
-                    *buttons     |= 1 << RETRO_DEVICE_ID_JOYPAD_START;
+               /* Support buttons that aren't supported by older mFi controller via "hotkey" combinations:
+                *
+                * LS + Menu => Select
+                * LT + Menu => L3
+                * RT + Menu => R3
+                */
+               if (gp.buttonMenu.pressed )
+               {
+                  if (gp.leftShoulder.pressed)
+                     *buttons     |= 1 << RETRO_DEVICE_ID_JOYPAD_SELECT;
+                  else if (gp.leftTrigger.pressed)
+                     *buttons     |= 1 << RETRO_DEVICE_ID_JOYPAD_L3;
+                  else if (gp.rightTrigger.pressed)
+                     *buttons     |= 1 << RETRO_DEVICE_ID_JOYPAD_R3;
+                  else
+                     *buttons     |= 1 << RETRO_DEVICE_ID_JOYPAD_START;
+               }
             }
         }
 #endif
@@ -143,6 +184,8 @@ static void apple_gamecontroller_joypad_poll_internal(GCController *controller,
         mfi_axes[slot][1]         = gp.leftThumbstick.yAxis.value * 32767.0f;
         mfi_axes[slot][2]         = gp.rightThumbstick.xAxis.value * 32767.0f;
         mfi_axes[slot][3]         = gp.rightThumbstick.yAxis.value * 32767.0f;
+        mfi_axes[slot][4]         = gp.leftTrigger.value * 32767.0f;
+        mfi_axes[slot][5]         = gp.rightTrigger.value * 32767.0f;
 
     }
     else if (controller.microGamepad)
@@ -177,7 +220,9 @@ static void apple_gamecontroller_joypad_poll(void)
     for (GCController *controller in [GCController controllers])
     {
        /* If we have not assigned a slot to this controller yet, ignore it. */
-       if (controller && (controller.playerIndex >= 0) && (controller.playerIndex < MAX_USERS))
+       if (  controller &&
+             (controller.playerIndex >= 0) && (controller.playerIndex < MAX_USERS) &&
+             !mfi_controller_is_siri_remote(controller))
           apple_gamecontroller_joypad_poll_internal(controller, (uint32_t)controller.playerIndex);
     }
 }
@@ -273,7 +318,7 @@ static void mfi_joypad_autodetect_add(unsigned autoconf_pad, const char *display
 #define MFI_RUMBLE_AVAIL API_AVAILABLE(macos(11.0), ios(14.0), tvos(14.0))
 @interface MFIRumbleController : NSObject
 @property (nonatomic, strong, readonly) GCController *controller;
-@property (nonatomic, strong) CHHapticEngine *engine MFI_RUMBLE_AVAIL;
+@property (nonatomic, strong) NSMutableSet<CHHapticEngine *> *engines MFI_RUMBLE_AVAIL;
 @property (nonatomic, strong, readonly) id<CHHapticPatternPlayer> strongPlayer MFI_RUMBLE_AVAIL;
 @property (nonatomic, strong, readonly) id<CHHapticPatternPlayer> weakPlayer MFI_RUMBLE_AVAIL;
 @end
@@ -290,34 +335,28 @@ static void mfi_joypad_autodetect_add(unsigned autoconf_pad, const char *display
             return self;
 
         _controller = controller;
-
-        [self setupEngine];
-        if (!self.engine)
-            return self;
-
-        _strongPlayer = [self createPlayerWithSharpness:1.0f];
-        _weakPlayer   = [self createPlayerWithSharpness:0.5f];
+        _engines = [[NSMutableSet alloc] init];
     }
     return self;
 }
 
-- (void)setupEngine MFI_RUMBLE_AVAIL
+- (id<CHHapticPatternPlayer>)createPlayerWithLocality:(GCHapticsLocality)locality andIntensity:(float)intensity MFI_RUMBLE_AVAIL
 {
     NSError *error;
-    if (self.engine)
-        return;
     if (!self.controller)
-        return;
+        return nil;
 
-    CHHapticEngine *engine = [self.controller.haptics createEngineWithLocality:GCHapticsLocalityDefault];
+    if (![self.controller.haptics.supportedLocalities containsObject:locality])
+        locality = GCHapticsLocalityDefault;
+    CHHapticEngine *engine = [self.controller.haptics createEngineWithLocality:locality];
     [engine startAndReturnError:&error];
     if (error)
-        return;
+        return nil;
 
-    self.engine = engine;
+    [self.engines addObject:engine];
 
     __weak MFIRumbleController *weakSelf = self;
-    self.engine.stoppedHandler = ^(CHHapticEngineStoppedReason stoppedReason)
+    engine.stoppedHandler = ^(CHHapticEngineStoppedReason stoppedReason)
     {
         MFIRumbleController *strongSelf = weakSelf;
         if (!strongSelf)
@@ -325,38 +364,25 @@ static void mfi_joypad_autodetect_add(unsigned autoconf_pad, const char *display
 
         [strongSelf shutdown];
     };
-    self.engine.resetHandler = ^{
+    engine.resetHandler = ^{
         MFIRumbleController *strongSelf = weakSelf;
         if (!strongSelf)
             return;
 
-        [strongSelf.engine startAndReturnError:nil];
+        for (CHHapticEngine *eng in strongSelf.engines)
+            [eng startAndReturnError:nil];
     };
-}
 
-- (id<CHHapticPatternPlayer>)createPlayerWithSharpness:(float)sharpness MFI_RUMBLE_AVAIL
-{
-    if (!self.controller)
-        return nil;
-
-    [self setupEngine];
-    if (!self.engine)
-        return nil;
-
-    CHHapticEventParameter *sharp, *intense;
+    CHHapticEventParameter *intense;
     CHHapticEvent *event;
     CHHapticPattern *pattern;
-    NSError *error;
 
-    sharp   = [[CHHapticEventParameter alloc]
-             initWithParameterID:CHHapticEventParameterIDHapticSharpness
-             value:sharpness];
     intense = [[CHHapticEventParameter alloc]
                initWithParameterID:CHHapticEventParameterIDHapticIntensity
-               value:1.0f];
+               value:intensity];
     event   = [[CHHapticEvent alloc]
              initWithEventType:CHHapticEventTypeHapticContinuous
-             parameters:[NSArray arrayWithObjects:sharp, intense, nil]
+             parameters:[NSArray arrayWithObjects:intense, nil]
              relativeTime:0
              duration:GCHapticDurationInfinite];
     pattern = [[CHHapticPattern alloc]
@@ -367,7 +393,7 @@ static void mfi_joypad_autodetect_add(unsigned autoconf_pad, const char *display
     if (error)
         return nil;
 
-    id<CHHapticPatternPlayer> player = [self.engine createPlayerWithPattern:pattern error:&error];
+    id<CHHapticPatternPlayer> player = [engine createPlayerWithPattern:pattern error:&error];
     if (error)
         return nil;
     [player stopAtTime:0 error:&error];
@@ -376,13 +402,13 @@ static void mfi_joypad_autodetect_add(unsigned autoconf_pad, const char *display
 
 - (id<CHHapticPatternPlayer>)strongPlayer
 {
-    _strongPlayer = _strongPlayer ?: [self createPlayerWithSharpness:1.0];
+    _strongPlayer = _strongPlayer ?: [self createPlayerWithLocality:GCHapticsLocalityAll andIntensity:1.0];
     return _strongPlayer;
 }
 
 - (id<CHHapticPatternPlayer>)weakPlayer
 {
-    _weakPlayer = _weakPlayer ?: [self createPlayerWithSharpness:0.5f];
+    _weakPlayer = _weakPlayer ?: [self createPlayerWithLocality:GCHapticsLocalityTriggers andIntensity:MFI_WEAK_RUMBLE];
     return _weakPlayer;
 }
 
@@ -392,7 +418,7 @@ static void mfi_joypad_autodetect_add(unsigned autoconf_pad, const char *display
     {
         _weakPlayer   = nil;
         _strongPlayer = nil;
-        self.engine   = nil;
+        [self.engines removeAllObjects];
     }
 }
 
@@ -412,13 +438,38 @@ static void apple_gamecontroller_joypad_connect(GCController *controller)
 
     /* Prevent same controller getting set twice */
     if ([mfiControllers containsObject:controller])
+    {
+        RARCH_DBG("[mfi] got connected notice for controller already connected\n");
         return;
+    }
+
+    if (@available(macOS 11, iOS 14, tvOS 14, *))
+    {
+        RARCH_DBG("[mfi] new controller connected:\n");
+        RARCH_DBG("[mfi]    name: %s\n", [controller.vendorName UTF8String]);
+        RARCH_DBG("[mfi]    category: %s\n", [controller.productCategory UTF8String]);
+        RARCH_DBG("[mfi]    has battery info: %s\n", controller.battery != nil ? "yes" : "no");
+        RARCH_DBG("[mfi]    has haptics: %s\n", controller.haptics != nil ? "yes" : "no");
+        RARCH_DBG("[mfi]    has light: %s\n", controller.light != nil ? "yes" : "no");
+        RARCH_DBG("[mfi]    has motion: %s\n", controller.motion != nil ? "yes" : "no");
+        RARCH_DBG("[mfi]    has microGamepad: %s\n", controller.microGamepad != nil ? "yes" : "no");
+        RARCH_DBG("[mfi]    has extendedGamepad: %s\n", controller.extendedGamepad != nil ? "yes" : "no");
+        RARCH_DBG("[mfi]    input profile:\n");
+        for (NSString *elem in controller.physicalInputProfile.elements.allKeys)
+        {
+            RARCH_DBG("[mfi]       %s\n", [elem UTF8String]);
+            GCControllerElement *element = controller.physicalInputProfile.elements[elem];
+            RARCH_DBG("[mfi]          analog: %s\n", element.analog ? "yes" : "no");
+            RARCH_DBG("[mfi]          localizedName: %s\n", [element.localizedName UTF8String]);
+        }
+    }
 
     if (mfi_controllers[desired_index] != (uint32_t)controller.hash)
     {
         /* Desired slot is unused, take it */
         if (!mfi_controllers[desired_index])
         {
+            RARCH_LOG("[mfi] controller given desired index %d\n", desired_index);
             controller.playerIndex = desired_index;
             mfi_controllers[desired_index] = (uint32_t)controller.hash;
         }
@@ -432,46 +483,58 @@ static void apple_gamecontroller_joypad_connect(GCController *controller)
                 if (mfi_controllers[i])
                     continue;
 
+                RARCH_LOG("[mfi] controller reassigned from desired %d to %d\n", desired_index, i);
                 mfi_controllers[i]     = (uint32_t)controller.hash;
                 controller.playerIndex = i;
                 break;
             }
+
+            if (i == MAX_MFI_CONTROLLERS)
+            {
+                /* shouldn't ever get here, this is an Apple limit */
+                RARCH_ERR("[mfi] too many connected controllers, ignoring\n");
+                return;
+            }
         }
-
-        [mfiControllers addObject:controller];
-
-        /* Move any non-game controllers (like the Siri remote) to the end */
-        if (mfiControllers.count > 1)
-        {
-           int newPlayerIndex                        = 0;
-           NSInteger connectedNonGameControllerIndex = NSNotFound;
-           NSUInteger index                          = 0;
-
-           for (GCController *connectedController in mfiControllers)
-           {
-              if (     connectedController.microGamepad    != nil
-                    && connectedController.extendedGamepad == nil )
-                 connectedNonGameControllerIndex = index;
-              index++;
-           }
-
-           if (connectedNonGameControllerIndex != NSNotFound)
-           {
-              GCController *nonGameController = [mfiControllers objectAtIndex:connectedNonGameControllerIndex];
-              [mfiControllers removeObjectAtIndex:connectedNonGameControllerIndex];
-              [mfiControllers addObject:nonGameController];
-           }
-           for (GCController *gc in mfiControllers)
-              gc.playerIndex = newPlayerIndex++;
-        }
-
-        if (controller.microGamepad && !controller.extendedGamepad)
-            return;
-
-        apple_gamecontroller_joypad_register(controller);
-        apple_gamecontroller_joypad_setup_haptics(controller);
-        mfi_joypad_autodetect_add((unsigned)controller.playerIndex, [controller.vendorName cStringUsingEncoding:NSUTF8StringEncoding]);
     }
+
+    [mfiControllers addObject:controller];
+
+    /* Move any non-game controllers (like the Siri remote) to the end */
+    if (mfiControllers.count > 1)
+    {
+        int newPlayerIndex                        = 0;
+        NSInteger connectedNonGameControllerIndex = NSNotFound;
+        NSUInteger index                          = 0;
+
+        for (GCController *connectedController in mfiControllers)
+        {
+            if (     connectedController.microGamepad    != nil
+                     && connectedController.extendedGamepad == nil )
+                connectedNonGameControllerIndex = index;
+            index++;
+        }
+
+        if (connectedNonGameControllerIndex != NSNotFound)
+        {
+            GCController *nonGameController = [mfiControllers objectAtIndex:connectedNonGameControllerIndex];
+            [mfiControllers removeObjectAtIndex:connectedNonGameControllerIndex];
+            [mfiControllers addObject:nonGameController];
+        }
+        for (GCController *gc in mfiControllers)
+            gc.playerIndex = newPlayerIndex++;
+    }
+
+    if (mfi_controller_is_siri_remote(controller))
+    {
+        RARCH_WARN("[mfi] ignoring siri remote as a controller\n");
+        return;
+    }
+
+    RARCH_LOG("[mfi] controller connected, beginning setup and autodetect\n");
+    apple_gamecontroller_joypad_register(controller);
+    apple_gamecontroller_joypad_setup_haptics(controller);
+    mfi_joypad_autodetect_add((unsigned)controller.playerIndex, [controller.vendorName cStringUsingEncoding:NSUTF8StringEncoding]);
 }
 
 static void apple_gamecontroller_joypad_disconnect(GCController* controller)
@@ -521,7 +584,7 @@ static void apple_gamecontroller_device_haptics_setup() IPHONE_RUMBLE_AVAIL
     };
 }
 
-static id<CHHapticPatternPlayer> apple_gamecontroller_device_haptics_create_player(float sharpness) IPHONE_RUMBLE_AVAIL
+static id<CHHapticPatternPlayer> apple_gamecontroller_device_haptics_create_player(float intensity) IPHONE_RUMBLE_AVAIL
 {
     if (!CHHapticEngine.capabilitiesForHardware.supportsHaptics)
         return nil;
@@ -530,20 +593,17 @@ static id<CHHapticPatternPlayer> apple_gamecontroller_device_haptics_create_play
     if (!deviceHapticEngine)
         return nil;
 
-    CHHapticEventParameter *sharp, *intense;
+    CHHapticEventParameter *intense;
     CHHapticEvent *event;
     CHHapticPattern *pattern;
     NSError *error;
 
-    sharp   = [[CHHapticEventParameter alloc]
-               initWithParameterID:CHHapticEventParameterIDHapticSharpness
-               value:sharpness];
     intense = [[CHHapticEventParameter alloc]
                initWithParameterID:CHHapticEventParameterIDHapticIntensity
-               value:1.0f];
+               value:intensity];
     event   = [[CHHapticEvent alloc]
                initWithEventType:CHHapticEventTypeHapticContinuous
-               parameters:[NSArray arrayWithObjects:sharp, intense, nil]
+               parameters:[NSArray arrayWithObjects:intense, nil]
                relativeTime:0
                duration:GCHapticDurationInfinite];
     pattern = [[CHHapticPattern alloc]
@@ -570,9 +630,9 @@ static id<CHHapticPatternPlayer> apple_gamecontroller_device_haptics_strong_play
 
 static id<CHHapticPatternPlayer> apple_gamecontroller_device_haptics_weak_player() IPHONE_RUMBLE_AVAIL
 {
-    if (!deviceStrongPlayer)
-        deviceStrongPlayer = apple_gamecontroller_device_haptics_create_player(0.5f);
-    return deviceStrongPlayer;
+    if (!deviceWeakPlayer)
+        deviceWeakPlayer = apple_gamecontroller_device_haptics_create_player(0.5f);
+    return deviceWeakPlayer;
 }
 #endif
 
@@ -633,14 +693,14 @@ static void apple_gamecontroller_joypad_get_buttons(unsigned port,
 static int16_t apple_gamecontroller_joypad_axis(
       unsigned port, uint32_t joyaxis)
 {
-    if (AXIS_NEG_GET(joyaxis) < 4)
+    if (AXIS_NEG_GET(joyaxis) < MAX_MFI_AXES)
     {
        int16_t axis = AXIS_NEG_GET(joyaxis);
        int16_t val  = mfi_axes[port][axis];
        if (val < 0)
           return val;
     }
-    else if (AXIS_POS_GET(joyaxis) < 4)
+    else if (AXIS_POS_GET(joyaxis) < MAX_MFI_AXES)
     {
        int16_t axis = AXIS_POS_GET(joyaxis);
        int16_t val  = mfi_axes[port][axis];
@@ -734,6 +794,7 @@ static bool apple_gamecontroller_joypad_set_rumble(unsigned pad,
                 else
                 {
                    float str = (float)strength / 65535.0f;
+                   if (type == RETRO_RUMBLE_WEAK) str *= MFI_WEAK_RUMBLE;
                    CHHapticDynamicParameter *param = [[CHHapticDynamicParameter alloc]
                       initWithParameterID:CHHapticDynamicParameterIDHapticIntensityControl
                                     value:str
