@@ -46,7 +46,11 @@ int msg_hash_get_help_enum(enum msg_hash_enums msg, char *s, size_t len)
          "\n",    STRLEN_CONST("\n"),
          "\n \n", STRLEN_CONST("\n \n"));
 
-   strlcpy(s, temp, len);
+   if (temp)
+   {
+      strlcpy(s, temp, len);
+      free((void*)temp);
+   }
    return ret;
 }
 
@@ -130,6 +134,10 @@ const char *get_user_language_iso639_1(bool limit)
          return "hu";
       case RETRO_LANGUAGE_BELARUSIAN:
          return "be";
+      case RETRO_LANGUAGE_GALICIAN:
+          return "gl";
+      case RETRO_LANGUAGE_NORWEGIAN:
+          return "no";
    }
    return "en";
 }
@@ -519,6 +527,30 @@ static const char *msg_hash_to_str_pt_br(enum msg_hash_enums msg)
    return "null";
 }
 
+static const char *msg_hash_to_str_gl(enum msg_hash_enums msg)
+{
+   switch (msg)
+   {
+#include "intl/msg_hash_gl.h"
+      default:
+         break;
+   }
+
+   return "null";
+}
+
+static const char *msg_hash_to_str_no(enum msg_hash_enums msg)
+{
+   switch (msg)
+   {
+#include "intl/msg_hash_no.h"
+      default:
+         break;
+   }
+
+   return "null";
+}
+
 #endif
 
 const char *msg_hash_to_str(enum msg_hash_enums msg)
@@ -624,6 +656,12 @@ const char *msg_hash_to_str(enum msg_hash_enums msg)
       case RETRO_LANGUAGE_BELARUSIAN:
          ret = msg_hash_to_str_be(msg);
          break;
+      case RETRO_LANGUAGE_GALICIAN:
+         ret = msg_hash_to_str_gl(msg);
+         break;
+      case RETRO_LANGUAGE_NORWEGIAN:
+         ret = msg_hash_to_str_no(msg);
+         break;
       default:
          break;
    }
