@@ -53,10 +53,18 @@
 /* Filesystem is in-memory anyway, use huge chunks since each
    read/write is a possible suspend to JS code */
 #define SAVE_STATE_CHUNK 4096 * 4096
-#elif defined(HAVE_LIBNX) || defined(_3DS)
-#define SAVE_STATE_CHUNK 4096 * 10
 #else
-#define SAVE_STATE_CHUNK 4096
+/* A low common denominator write chunk size.  On a slow 
+  (speed class 6) SD card, we can write 6MB/s.  That gives us 
+  roughly 100KB/frame.  
+  This means we can write savestates with one syscall for cores 
+  with less than 100KB of state. Class 10 is the standard now 
+  even for lousy cards and supports 10MB/s, so you may prefer 
+  to put this to 170KB. This all assumes that task_save's loop
+  is iterated once per frame at 60 FPS; if it's updated less
+  frequently this number could be doubled or quadrupled depending
+  on the tickrate. */
+#define SAVE_STATE_CHUNK 100 * 1024
 #endif
 
 #define RASTATE_VERSION 1
