@@ -1,6 +1,8 @@
 #ifndef COCOA_APPLE_PLATFORM_H
 #define COCOA_APPLE_PLATFORM_H
 
+extern bool RAIsVoiceOverRunning(void);
+
 #if TARGET_OS_TV
 #include "config_file.h"
 extern config_file_t *open_userdefaults_config_file(void);
@@ -8,6 +10,10 @@ extern void write_userdefaults_config_file(void);
 extern void update_topshelf(void);
 #endif
 
+#if TARGET_OS_IOS
+extern void ios_show_file_sheet(void);
+#endif
+
 #ifdef __OBJC__
 
 #ifdef HAVE_METAL
